<?php

/*
 * This file is used for controlling the data for the dashboard page
 */

// Setup cron jobs

if ( ! wp_next_scheduled('initialize_content_fire_stats_daily_cron')) {
	wp_schedule_event( time(), 'daily', 'initialize_content_fire_stats_daily_cron');
}

if ( ! wp_next_scheduled('setup_content_fire_email_stats_cron')) {
	wp_schedule_event( time(), 'daily', 'setup_content_fire_email_stats_cron');
}

if (!wp_next_scheduled('purge_content_fire_transients_cron')) {
	wp_schedule_event( time(), 'daily', 'purge_content_fire_transients_cron');
}

include_once(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . '/admin/model/db.php');
include_once(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . '/admin/model/list-table.php');

// Init model and controller classes

$nnrobots_content_fire_list_table = new NNRobots_Content_Fire_List_Table();
$nnrobots_content_fire_db = new NNRobots_Content_Fire_DB();

// Activate / Deactivate

if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "active") {

	// Check nonce

	if (isset($_REQUEST['wp_nonce']) && wp_verify_nonce($_REQUEST['wp_nonce'], self::$prefix . 'activate'))
		$nnrobots_content_fire_db->set_active($_GET["content_fire_id"], $_GET["set_action"]);
}

// Delete

if(isset($_REQUEST['action']) && $_REQUEST["action"] == "delete") {

	// Check nonce

	if (isset($_REQUEST['wp_nonce']) && wp_verify_nonce($_REQUEST['wp_nonce'], self::$prefix . 'delete')) {

		// Check if content fire is currently in an A/B Test

		$nnrobots_content_fire_db = new NNRobots_Content_Fire_DB();
		$content_fire = $nnrobots_content_fire_db->get_data_from_id($_GET['content_fire_id']);
		$content_fire['args'] = unserialize($content_fire['args']);
		$ab_content_fire = $nnrobots_content_fire_db->get_data_from_id($content_fire['args']['ab_testing']['content_fire_id']);

		if (isset($ab_content_fire)) {

			$ab_content_fire['social']         = unserialize($ab_content_fire['social']);
			$ab_content_fire['news_letter']    = unserialize($ab_content_fire['news_letter']);
			$ab_content_fire['template']       = unserialize($ab_content_fire['template']);
			$ab_content_fire['trigger']        = unserialize($ab_content_fire['trigger']);
			$ab_content_fire['style']          = unserialize($ab_content_fire['style']);
			$ab_content_fire['args']           = unserialize($ab_content_fire['args']);

			$ab_content_fire['args']['ab_testing']['active'] = false;
			$ab_content_fire['args']['ab_testing']['content_fire_id'] = '0';
			$ab_content_fire['args']['ab_testing']['start_date'] = '0';
			$nnrobots_content_fire_db->update_data($ab_content_fire);

		}

		// Delete record

		if(isset($_GET["content_fire_id"])) {
			$nnrobots_content_fire_db->delete_data(esc_attr($_GET["content_fire_id"]));
		}

		?>
		<script type="text/javascript">
			window.location= "<?php echo get_admin_url() ;?>admin.php?page=<?php echo self::$dashboard_page; ?>";
		</script>
		<?php
	}
}

// Preview

if (isset($_REQUEST["action"]) && $_REQUEST["action"] == "preview") {

	$content_fire_preview = '';

	// Check nonce

	if (isset($_REQUEST['wp_nonce']) && wp_verify_nonce($_REQUEST['wp_nonce'], self::$prefix . 'preview')) {

		global $wpdb;

		$data = $wpdb->get_results($wpdb->prepare("SELECT * FROM `" . NNRobots_Content_Fire_DB::getTableName() . "` WHERE id = %d", $_REQUEST['content_fire_id']), 'ARRAY_A');

		$args = unserialize($data[0]['args']);

		if ($args['placement']['type'] == 'none') {
			$content_fire_preview = NNRobots_Content_Fire_Functions::generate_code($data[0], unserialize($data[0]['news_letter']), true);
		} else {
			$content_fire_preview = NNRobots_Content_Fire_Functions::generate_code($data[0], unserialize($data[0]['news_letter']));
		}

	}

	echo $content_fire_preview;
}

// Dismiss notice

if (isset($_GET['action']) && $_GET['action'] != '' && isset($_GET['notice']) && $_GET['notice'] != '') {
	delete_transient(self::$prefix . 'admin_notice_' . $_GET['notice']);

	?>
	<script type="text/javascript">
		window.location = "<?php echo get_admin_url(); ?>admin.php?page=<?php echo self::$dashboard_page; ?>";
	</script>
	<?php
}

require(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . '/admin/views/dashboard.php');

wp_localize_script(self::$prefix . 'admin_js', 'nnr_cf_data', array(
	'prefix_dash' 		=> self::$prefix_dash,
	'activate_text' 	=> __('Activate', self::$text_domain),
	'deactivate_text' 	=> __('Deactivate', self::$text_domain),
));